#define ExtraIncDir	/sw/include
#define EtcX11Directory	ProjectRoot/etc
#define HasPosixThreads       YES
#define HasThreadSafeAPI      NO
#define CppCmd                   cpp
#define CcCmd                    cc
#define CplusplusCmd             c++
